==> dde-launcher_3.0.3.orig.tar.xz: dde-launcher-3.0.3/translations/dde-launcher_gl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="gl" version="2.1">
<context>
    <name>ConfirmUninstallDialog</name>
    <message>
        <location filename="../dialogs/confirmuninstalldialog.cpp" line="12"/>
        <source>All dependencies will be removed together</source>
        <translation>Eliminaranse todas as dependencias xuntas</translation>
    </message>
    <message>
        <location filename="../dialogs/confirmuninstalldialog.cpp" line="15"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../dialogs/confirmuninstalldialog.cpp" line="15"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>DisplayModeFrame</name>
    <message>
        <location filename="../views/displaymodeframe.cpp" line="38"/>
        <source>By name</source>
        <translation>Por nome</translation>
    </message>
    <message>
        <location filename="../views/displaymodeframe.cpp" line="40"/>
        <source>By category (icon)</source>
        <translation>Por categoría (icona)</translation>
    </message>
    <message>
        <location filename="../views/displaymodeframe.cpp" line="42"/>
        <source>By category (text)</source>
        <translation>Por categoría (texto)</translation>
    </message>
    <message>
        <location filename="../views/displaymodeframe.cpp" line="44"/>
        <source>By time installed</source>
        <translation>Por tempo instalado</translation>
    </message>
    <message>
        <location filename="../views/displaymodeframe.cpp" line="46"/>
        <source>By frequency</source>
        <translation>Por frecuencia</translation>
    </message>
</context>
<context>
    <name>LauncherApp</name>
    <message>
        <location filename="../app/launcherapp.cpp" line="47"/>
        <source>Are you sure to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <location filename="../controller/menucontroller.cpp" line="70"/>
        <source>Open(_O)</source>
        <translation>Abrir (_A)</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="74"/>
        <source>Remove from desktop</source>
        <translation>Eliminar do escritorio</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="76"/>
        <source>Send to desktop(_E)</source>
        <translation>Enviar ao escritorio (_T)</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="80"/>
        <source>Remove from dock</source>
        <translation>Eliminar da doca</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="82"/>
        <source>Send to dock(_C)</source>
        <translation>Enviar á doca (_C)</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="87"/>
        <source>Remove from startup(_R)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="89"/>
        <source>Add to startup(_A)</source>
        <translation>Angadir ao inicio (_G)</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="91"/>
        <source>Uninstall</source>
        <translation>Desinstalar</translation>
    </message>
</context>
</TS>

==> dde-launcher_4.3.2.2.orig.tar.xz: dde-launcher-4.3.2.2/translations/dde-launcher_gl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="gl" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Confirm</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Uninstall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open by proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send to dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add to startup</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Confirm</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Logout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suspend</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shutdown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shutdown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Logout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suspend</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
